@@ -40,3 +40,10 @@ extern guint FoV;
 extern gdouble Phi, Theta, Psi;
 extern gdouble Red, Green, Blue;
 extern GConfClient *conf_client;
+
+#ifdef GTK_IS_26
+#define SET_ICON(w) gtk_window_set_icon_name (GTK_WINDOW (w), "gcrystal")
+#else
+extern GdkPixbuf *icon;
+#define SET_ICON(w) gtk_window_set_icon (GTK_WINDOW (w), icon)
+#endif
